note 46998 deleted from function.include by sean
| From: | sean@php.net | Date: | Sat, 30 Oct 2004 00:48:26 +0000 |
| Subject: | note 46998 deleted from function.include by sean | ||
| References: | 1 | Groups: | php.notes |
| Request: | Send a blank email to php-notes+get-79339@lists.php.net to get a copy of this message | ||
Note Submitter: sectionthirty1 at yahoo dot com
----
Please be aware that require and include are many times slower than fread() or file().
My average times testing a 3.64MB html file. (dual xeon proc with 1 GIG of ram)
.2 seconds using include() and require()
.033 seconds using fread()
.026 seconds using file()
----
Reason: useless note